@@ -14,7 +14,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with RawTherapee.  If not, see <http://www.gnu.org/licenses/>.
+ *  along with RawTherapee.  If not, see <https://www.gnu.org/licenses/>.
  */
 #include "ffmanager.h"
 #include "../rtgui/options.h"
@@ -231,8 +231,11 @@ void ffInfo::updateRawImage()
 
 // ************************* class FFManager *********************************
 
-void FFManager::init( Glib::ustring pathname )
+void FFManager::init(const Glib::ustring& pathname)
 {
+    if (pathname.empty()) {
+        return;
+    }
     std::vector<Glib::ustring> names;
 
     auto dir = Gio::File::create_for_path (pathname);
@@ -274,8 +277,8 @@ void FFManager::init( Glib::ustring pathname )
             } else {
                 printf( "%s: MEAN of \n    ", i.key().c_str());
 
-                for( std::list<Glib::ustring>::iterator iter = i.pathNames.begin(); iter != i.pathNames.end(); ++iter  ) {
-                    printf( "%s, ", iter->c_str() );
+                for(std::list<Glib::ustring>::iterator path = i.pathNames.begin(); path != i.pathNames.end(); ++path) {
+                    printf("%s, ", path->c_str());
                 }
 
                 printf("\n");
