@@ -14,7 +14,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with RawTherapee.  If not, see <http://www.gnu.org/licenses/>.
+ *  along with RawTherapee.  If not, see <https://www.gnu.org/licenses/>.
  */
 #include "image16.h"
 #include "imagefloat.h"
@@ -74,7 +74,7 @@ void Image16::getScanline(int row, unsigned char* buffer, int bps, bool isFloat)
     }
 }
 
-void Image16::setScanline(int row, unsigned char* buffer, int bps, unsigned int numSamples)
+void Image16::setScanline(int row, const unsigned char* buffer, int bps, unsigned int numSamples)
 {
 
     if (data == nullptr) {
@@ -101,7 +101,7 @@ void Image16::setScanline(int row, unsigned char* buffer, int bps, unsigned int
         }
 
         case (IIOSF_UNSIGNED_SHORT): {
-            unsigned short* sbuffer = (unsigned short*) buffer;
+            const unsigned short* sbuffer = (const unsigned short*) buffer;
             int ix = 0;
 
             for (int i = 0; i < width; ++i) {
