@@ -14,7 +14,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with RawTherapee.  If not, see <http://www.gnu.org/licenses/>.
+ *  along with RawTherapee.  If not, see <https://www.gnu.org/licenses/>.
  */
 #include "improccoordinator.h"
 #include "curves.h"
@@ -277,6 +277,18 @@ void ImProcCoordinator::updatePreviewImage(int todo, bool panningRelatedChange)
             imgsrc->getRAWHistogram(histRedRaw, histGreenRaw, histBlueRaw);
 
             highDetailPreprocessComputed = highDetailNeeded;
+
+            // After preprocess, run film negative processing if enabled
+            if (
+                (todo & M_RAW)
+                && (
+                    imgsrc->getSensorType() == ST_BAYER
+                    || imgsrc->getSensorType() == ST_FUJI_XTRANS
+                )
+                && params->filmNegative.enabled
+            ) {
+                imgsrc->filmNegativeProcess(params->filmNegative);
+            }
         }
 
         /*
@@ -778,7 +790,7 @@ void ImProcCoordinator::updatePreviewImage(int todo, bool panningRelatedChange)
             ipf.labColorCorrectionRegions(nprevl);
 
             if ((params->colorappearance.enabled && !params->colorappearance.tonecie) || (!params->colorappearance.enabled)) {
-                ipf.EPDToneMap(nprevl, 5, scale);
+                ipf.EPDToneMap(nprevl, 0, scale);
             }
 
             // for all treatments Defringe, Sharpening, Contrast detail , Microcontrast they are activated if "CIECAM" function are disabled
@@ -922,7 +934,7 @@ void ImProcCoordinator::updatePreviewImage(int todo, bool panningRelatedChange)
                 CAMBrightCurveJ.dirty = true;
                 CAMBrightCurveQ.dirty = true;
 
-                ipf.ciecam_02float(ncie, float (adap), pW, 2, nprevl, params.get(), customColCurve1, customColCurve2, customColCurve3, histLCAM, histCCAM, CAMBrightCurveJ, CAMBrightCurveQ, CAMMean, 5, scale, execsharp, d, dj, yb, 1);
+                ipf.ciecam_02float(ncie, float (adap), pW, 2, nprevl, params.get(), customColCurve1, customColCurve2, customColCurve3, histLCAM, histCCAM, CAMBrightCurveJ, CAMBrightCurveQ, CAMMean, 0 , scale, execsharp, d, dj, yb, 1);
 
                 if ((params->colorappearance.autodegree || params->colorappearance.autodegreeout) && acListener && params->colorappearance.enabled) {
                     acListener->autoCamChanged(100.* (double)d, 100.* (double)dj);
@@ -1250,6 +1262,31 @@ void ImProcCoordinator::getSpotWB(int x, int y, int rect, double& temp, double&
     }
 }
 
+bool ImProcCoordinator::getFilmNegativeExponents(int xA, int yA, int xB, int yB, std::array<float, 3>& newExps)
+{
+    MyMutex::MyLock lock(mProcessing);
+
+    const auto xlate =
+        [this](int x, int y) -> Coord2D
+        {
+            const std::vector<Coord2D> points = {Coord2D(x, y)};
+
+            std::vector<Coord2D> red;
+            std::vector<Coord2D> green;
+            std::vector<Coord2D> blue;
+            ipf.transCoord(fw, fh, points, red, green, blue);
+
+            return green[0];
+        };
+
+    const int tr = getCoarseBitMask(params->coarse);
+
+    const Coord2D p1 = xlate(xA, yA);
+    const Coord2D p2 = xlate(xB, yB);
+
+    return imgsrc->getFilmNegativeExponents(p1, p2, tr, params->filmNegative, newExps);
+}
+
 void ImProcCoordinator::getAutoCrop(double ratio, int &x, int &y, int &w, int &h)
 {
 
@@ -1477,13 +1514,13 @@ void ImProcCoordinator::process()
 
     while (changeSinceLast) {
         const bool panningRelatedChange =
-               params->toneCurve != nextParams->toneCurve
+               params->toneCurve.isPanningRelatedChange(nextParams->toneCurve)
             || params->labCurve != nextParams->labCurve
             || params->localContrast != nextParams->localContrast
             || params->rgbCurves != nextParams->rgbCurves
             || params->colorToning != nextParams->colorToning
             || params->vibrance != nextParams->vibrance
-            || params->wb != nextParams->wb
+            || params->wb.isPanningRelatedChange(nextParams->wb)
             || params->colorappearance != nextParams->colorappearance
             || params->epd != nextParams->epd
             || params->fattal != nextParams->fattal
