@@ -14,7 +14,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with RawTherapee.  If not, see <http://www.gnu.org/licenses/>.
+ *  along with RawTherapee.  If not, see <https://www.gnu.org/licenses/>.
  */
 #pragma once
 
@@ -284,6 +284,7 @@ struct ToneCurveParams {
 
     ToneCurveParams();
 
+    bool isPanningRelatedChange(const ToneCurveParams& other) const;
     bool operator ==(const ToneCurveParams& other) const;
     bool operator !=(const ToneCurveParams& other) const;
 
@@ -597,6 +598,7 @@ struct WBParams {
 
     WBParams();
 
+    bool isPanningRelatedChange(const WBParams& other) const;
     bool operator ==(const WBParams& other) const;
     bool operator !=(const WBParams& other) const;
 
@@ -728,7 +730,6 @@ struct DirPyrDenoiseParams {
     bool operator !=(const DirPyrDenoiseParams& other) const;
 
     void getCurves(NoiseCurve& lCurve, NoiseCurve& cCurve) const;
-
 };
 
 // EPD related parameters.
@@ -1056,7 +1057,6 @@ struct ColorManagementParams {
     bool operator !=(const ColorManagementParams& other) const;
 };
 
-
 /**
   * Parameters for metadata handling
   */
@@ -1295,7 +1295,6 @@ struct HSVEqualizerParams {
     bool operator !=(const HSVEqualizerParams& other) const;
 };
 
-
 /**
  *  Film simualtion params
  */
@@ -1310,7 +1309,6 @@ struct FilmSimulationParams {
     bool operator !=(const FilmSimulationParams& other) const;
 };
 
-
 struct SoftLightParams {
     bool enabled;
     int strength;
@@ -1334,7 +1332,6 @@ struct DehazeParams {
     bool operator!=(const DehazeParams &other) const;
 };
 
-
 /**
   * Parameters for RAW demosaicing, common to all sensor type
   */
@@ -1501,6 +1498,21 @@ struct RAWParams {
     static Glib::ustring getFlatFieldBlurTypeString(FlatFieldBlurType type);
 };
 
+/**
+  * Parameters of film negative
+  */
+struct FilmNegativeParams {
+    bool enabled;
+    double redRatio;
+    double greenExp;
+    double blueRatio;
+
+    FilmNegativeParams();
+
+    bool operator ==(const FilmNegativeParams& other) const;
+    bool operator !=(const FilmNegativeParams& other) const;
+};
+
 /**
   * This class holds all the processing parameters applied on the images
   */
@@ -1549,6 +1561,7 @@ public:
     FilmSimulationParams    filmSimulation;  ///< film simulation parameters
     SoftLightParams         softlight;       ///< softlight parameters
     DehazeParams            dehaze;          ///< dehaze parameters
+    FilmNegativeParams      filmNegative;    ///< Film negative parameters
     int                     rank;            ///< Custom image quality ranking
     int                     colorlabel;      ///< Custom color label
     bool                    inTrash;         ///< Marks deleted image
@@ -1623,8 +1636,8 @@ class PartialProfile :
 {
 public:
     PartialProfile(bool createInstance = false, bool paramsEditedValue = false);
-    PartialProfile(ProcParams* pp, ParamsEdited* pe = nullptr, bool fullCopy = false);
-    PartialProfile(const ProcParams* pp, const ParamsEdited* pe = nullptr);
+    explicit PartialProfile(ProcParams* pp, ParamsEdited* pe = nullptr, bool fullCopy = false);
+    explicit PartialProfile(const ProcParams* pp, const ParamsEdited* pe = nullptr);
     void deleteInstance();
     void clearGeneral();
     int  load(const Glib::ustring& fName);
