@@ -14,7 +14,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with RawTherapee.  If not, see <http://www.gnu.org/licenses/>.
+ *  along with RawTherapee.  If not, see <https://www.gnu.org/licenses/>.
  */
 #include "batchqueuebuttonset.h"
 
@@ -27,6 +27,10 @@ Cairo::RefPtr<RTSurface> BatchQueueButtonSet::cancelIcon;
 Cairo::RefPtr<RTSurface> BatchQueueButtonSet::headIcon;
 Cairo::RefPtr<RTSurface> BatchQueueButtonSet::tailIcon;
 
+Glib::ustring BatchQueueButtonSet::moveHeadToolTip;
+Glib::ustring BatchQueueButtonSet::moveEndToolTip;
+Glib::ustring BatchQueueButtonSet::cancelJobToolTip;
+
 BatchQueueButtonSet::BatchQueueButtonSet (BatchQueueEntry* myEntry)
 {
 
@@ -34,10 +38,13 @@ BatchQueueButtonSet::BatchQueueButtonSet (BatchQueueEntry* myEntry)
         cancelIcon = Cairo::RefPtr<RTSurface>(new RTSurface("cancel-small.png"));
         headIcon = Cairo::RefPtr<RTSurface>(new RTSurface("goto-start-small.png"));
         tailIcon = Cairo::RefPtr<RTSurface>(new RTSurface("goto-end-small.png"));
+        moveHeadToolTip = M("FILEBROWSER_POPUPMOVEHEAD");
+        moveEndToolTip = M("FILEBROWSER_POPUPMOVEEND");
+        cancelJobToolTip = M("FILEBROWSER_POPUPCANCELJOB");
         iconsLoaded = true;
     }
 
-    add (new LWButton (headIcon, 8, myEntry, LWButton::Left, LWButton::Center, M("FILEBROWSER_POPUPMOVEHEAD")));
-    add (new LWButton (tailIcon, 9, myEntry, LWButton::Left, LWButton::Center, M("FILEBROWSER_POPUPMOVEEND")));
-    add (new LWButton (cancelIcon, 10, myEntry, LWButton::Right, LWButton::Center, M("FILEBROWSER_POPUPCANCELJOB")));
+    add(new LWButton(headIcon, 8, myEntry, LWButton::Left, LWButton::Center, &moveHeadToolTip));
+    add(new LWButton(tailIcon, 9, myEntry, LWButton::Left, LWButton::Center, &moveEndToolTip));
+    add(new LWButton(cancelIcon, 10, myEntry, LWButton::Right, LWButton::Center, &cancelJobToolTip));
 }
